==> cscec5b-dataexchange-impl-3.0.1-20211124.083956-13-sources.jar: com/ejianc/business/dataexchange/controller/api/CmContractApi.java <==
package com.ejianc.business.dataexchange.controller.api;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.dataexchange.service.ICmContractService;
import com.ejianc.business.dataexchange.vo.CmContract;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

import static com.ejianc.framework.skeleton.template.BaseServiceImpl.changeToQueryWrapper;


@RestController
@RequestMapping("/api/")
public class CmContractApi {

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private ICmContractService cmContractService;


    @RequestMapping(value = "queryMatContractRef", method= RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<CmContract>> queryMatContractRef(
            @RequestParam(value = "pkCorp", required=false) String pkCorp,
            @RequestParam(defaultValue = "1") Integer pageNumber,
            @RequestParam(defaultValue = "10") Integer pageSize,
            @RequestParam(value = "condition", required = false) String condition,
            @RequestParam(value = "searchText", required = false) String searchText) {
        /** 模糊搜索配置字段示例 */
        QueryParam queryParam = new QueryParam();
        queryParam.setPageIndex(pageNumber);
        queryParam.setPageSize(pageSize);
        queryParam.setSearchText(searchText);
        List<String> fuzzyFields = queryParam.getFuzzyFields();
        fuzzyFields.add("contractname");
        fuzzyFields.add("contractcode");
        fuzzyFields.add("suppliername");
        /*if(StringUtils.isNotEmpty(pkCorp)){
            queryParam.getParams().put("pkCorp", new Parameter(QueryParam.EQ, pkCorp));
        }*/
        /** 租户隔离 */
        Long supplierId = null;
        String pkProject = null;
        String pkSupplier = null;
        String pkBilltype = "992C";
        if(org.apache.commons.lang3.StringUtils.isNotBlank(condition)) {
            Map<String, Object> conditionMap = JSONObject.parseObject(condition, Map.class);
            if(null != conditionMap.get("supplierId")) {
                supplierId = Long.valueOf(conditionMap.get("supplierId").toString());
                logger.info("参数supplierId--"+supplierId);
            }
            if(null != conditionMap.get("pkProject")) {
                pkProject = conditionMap.get("pkProject").toString();
                logger.info("pkProject--"+pkProject);
            }
            if(null != conditionMap.get("pkSupplier")) {
                pkSupplier = conditionMap.get("pkSupplier").toString();
                logger.info("pkSupplier--"+pkSupplier);
            }
            if(null != conditionMap.get("contractType") && 1 == Integer.parseInt((String) conditionMap.get("contractType"))) {
                pkBilltype = "992D";
            }
        }
        if(StringUtils.isNotEmpty(pkProject)){
            //queryParam.getParams().put("pk_project", new Parameter(QueryParam.EQ, pkProject));
            if(pkCorp == null || StringUtils.isEmpty(pkCorp)) {
                pkCorp = pkProject.substring(0,4);
            }
        }
        if(StringUtils.isNotEmpty(pkSupplier)){
            queryParam.getParams().put("pkSupplier", new Parameter(QueryParam.EQ, pkSupplier));
        }
        //queryParam.getOrderMap().put("checkDate", QueryParam.DESC);
        //IPage<Stordoc> page = calBodyService.queryPage(queryParam,false);
        Page<CmContract> page = new Page<>((long)queryParam.getPageIndex(), (long)queryParam.getPageSize());
        QueryWrapper wrapper = changeToQueryWrapper(queryParam);
        List<CmContract> listres = cmContractService.queryMatCmContract(page,wrapper,supplierId,pkCorp, pkBilltype,pkProject);
        IPage<CmContract> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(listres);
        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    @RequestMapping(value = "querySubContractRef", method= RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<CmContract>> querySubContractRef(
            @RequestParam(value = "pkCorp", required=false) String pkCorp,
            @RequestParam(defaultValue = "1") Integer pageNumber,
            @RequestParam(defaultValue = "10") Integer pageSize,
            @RequestParam(value = "condition", required = false) String condition,
            @RequestParam(value = "searchText", required = false) String searchText) {
        /** 模糊搜索配置字段示例 */
        QueryParam queryParam = new QueryParam();
        queryParam.setPageIndex(pageNumber);
        queryParam.setPageSize(pageSize);
        queryParam.setSearchText(searchText);
        List<String> fuzzyFields = queryParam.getFuzzyFields();
        fuzzyFields.add("contractname");
        fuzzyFields.add("contractcode");
        fuzzyFields.add("suppliername");
        /*if(StringUtils.isNotEmpty(pkCorp)){
            queryParam.getParams().put("pkCorp", new Parameter(QueryParam.EQ, pkCorp));
        }*/
        /** 租户隔离 */
        Long supplierId = null;
        String pkProject = null;
        String pkSupplier = null;
        if(org.apache.commons.lang3.StringUtils.isNotBlank(condition)) {
            Map<String, Object> conditionMap = JSONObject.parseObject(condition, Map.class);
            if(null != conditionMap.get("supplierId")) {
                supplierId = Long.valueOf(conditionMap.get("supplierId").toString());
                logger.info("参数supplierId--"+supplierId);
            }
            if(null != conditionMap.get("pkProject")) {
                pkProject = conditionMap.get("pkProject").toString();
                logger.info("pkProject--"+pkProject);
            }
            if(null != conditionMap.get("pkSupplier")) {
                pkSupplier = conditionMap.get("pkSupplier").toString();
                logger.info("pkSupplier--"+pkSupplier);
            }
        }
        if(StringUtils.isNotEmpty(pkProject)){
            queryParam.getParams().put("pk_project", new Parameter(QueryParam.EQ, pkProject));
        }
        if(StringUtils.isNotEmpty(pkSupplier)){
            queryParam.getParams().put("pk_supplier", new Parameter(QueryParam.EQ, pkSupplier));
        }
        //queryParam.getOrderMap().put("checkDate", QueryParam.DESC);
        //IPage<Stordoc> page = calBodyService.queryPage(queryParam,false);
        Page<CmContract> page = new Page<>((long)queryParam.getPageIndex(), (long)queryParam.getPageSize());
        QueryWrapper wrapper = changeToQueryWrapper(queryParam);
        List<CmContract> listres = cmContractService.querySubCmContract(page,wrapper,supplierId,pkCorp);
        IPage<CmContract> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(listres);
        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    @RequestMapping(value = "queryMatContractById", method= RequestMethod.GET)
    @ResponseBody
    public CommonResponse<CmContract> queryMatContractById(@RequestParam(value = "contractId") String contractId) {

        logger.info("传入参数contractId--controller---: {}", contractId);
        CmContract entity = cmContractService.queryMatContractById(contractId);
        return CommonResponse.success("查询单个合同实体成功！", entity);
    }
}

==> cscec5b-dataexchange-impl-3.0.1-20240726.114344-97-sources.jar: com/ejianc/business/dataexchange/controller/api/CmContractApi.java <==
package com.ejianc.business.dataexchange.controller.api;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.dataexchange.service.ICmContractService;
import com.ejianc.business.dataexchange.vo.CmContract;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import static com.ejianc.framework.skeleton.template.BaseServiceImpl.changeToQueryWrapper;


@RestController
@RequestMapping("/api/")
public class CmContractApi {

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private ICmContractService cmContractService;

    @Autowired
    private IOrgApi orgApi;

    @RequestMapping(value = "queryMatContractRef", method= RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<CmContract>> queryMatContractRef(
            @RequestParam(value = "pkCorp", required=false) String pkCorp,
            @RequestParam(defaultValue = "1") Integer pageNumber,
            @RequestParam(defaultValue = "10") Integer pageSize,
            @RequestParam(value = "condition", required = false) String condition,
            @RequestParam(value = "searchText", required = false) String searchText) {
        /** 模糊搜索配置字段示例 */
        QueryParam queryParam = new QueryParam();
        queryParam.setPageIndex(pageNumber);
        queryParam.setPageSize(pageSize);
        queryParam.setSearchText(searchText);
        List<String> fuzzyFields = queryParam.getFuzzyFields();
        fuzzyFields.add("contractname");
        fuzzyFields.add("contractcode");
        fuzzyFields.add("suppliername");
        /*if(StringUtils.isNotEmpty(pkCorp)){
            queryParam.getParams().put("pkCorp", new Parameter(QueryParam.EQ, pkCorp));
        }*/
        /** 租户隔离 */
        Long supplierId = null;
        String pkProject = null;
        String pkSupplier = null;
        String pkBilltype = "992C";
        if(org.apache.commons.lang3.StringUtils.isNotBlank(condition)) {
            Map<String, Object> conditionMap = JSONObject.parseObject(condition, Map.class);
            if(null != conditionMap.get("supplierId")) {
                supplierId = Long.valueOf(conditionMap.get("supplierId").toString());
                logger.info("参数supplierId--"+supplierId);
            }
            if(null != conditionMap.get("pkProject")) {
                pkProject = conditionMap.get("pkProject").toString();
                logger.info("pkProject--"+pkProject);
            }
            if(null != conditionMap.get("pkSupplier")) {
                pkSupplier = conditionMap.get("pkSupplier").toString();
                logger.info("pkSupplier--"+pkSupplier);
            }
            if(null != conditionMap.get("contractType") && 1 == Integer.parseInt((String) conditionMap.get("contractType"))) {
                pkBilltype = "992D";
            }
        }
        if(StringUtils.isNotEmpty(pkProject)){
            //queryParam.getParams().put("pk_project", new Parameter(QueryParam.EQ, pkProject));
            if(pkCorp == null || StringUtils.isEmpty(pkCorp)) {
                pkCorp = pkProject.substring(0,4);
            }
        }
        if(StringUtils.isNotEmpty(pkSupplier)){
            queryParam.getParams().put("pkSupplier", new Parameter(QueryParam.EQ, pkSupplier));
        }
        //queryParam.getOrderMap().put("checkDate", QueryParam.DESC);
        //IPage<Stordoc> page = calBodyService.queryPage(queryParam,false);
        Page<CmContract> page = new Page<>((long)queryParam.getPageIndex(), (long)queryParam.getPageSize());
        QueryWrapper wrapper = changeToQueryWrapper(queryParam);
        List<CmContract> listres = cmContractService.queryMatCmContract(page,wrapper,supplierId,pkCorp, pkBilltype,pkProject);
        IPage<CmContract> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(listres);
        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    @RequestMapping(value = "querySubContractRef", method= RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<CmContract>> querySubContractRef(
            @RequestParam(value = "pkCorp", required=false) String pkCorp,
            @RequestParam(defaultValue = "1") Integer pageNumber,
            @RequestParam(defaultValue = "10") Integer pageSize,
            @RequestParam(value = "condition", required = false) String condition,
            @RequestParam(value = "searchText", required = false) String searchText) {
        /** 模糊搜索配置字段示例 */
        QueryParam queryParam = new QueryParam();
        queryParam.setPageIndex(pageNumber);
        queryParam.setPageSize(pageSize);
        queryParam.setSearchText(searchText);
        List<String> fuzzyFields = queryParam.getFuzzyFields();
        fuzzyFields.add("contractname");
        fuzzyFields.add("contractcode");
        fuzzyFields.add("suppliername");
        /*if(StringUtils.isNotEmpty(pkCorp)){
            queryParam.getParams().put("pkCorp", new Parameter(QueryParam.EQ, pkCorp));
        }*/
        /** 租户隔离 */
        Long supplierId = null;
        String pkProject = null;
        String pkSupplier = null;
        if(org.apache.commons.lang3.StringUtils.isNotBlank(condition)) {
            Map<String, Object> conditionMap = JSONObject.parseObject(condition, Map.class);
            if(null != conditionMap.get("supplierId")) {
                supplierId = Long.valueOf(conditionMap.get("supplierId").toString());
                logger.info("参数supplierId--"+supplierId);
            }
            if(null != conditionMap.get("pkProject")) {
                pkProject = conditionMap.get("pkProject").toString();
                logger.info("pkProject--"+pkProject);
            }
            if(null != conditionMap.get("pkSupplier")) {
                pkSupplier = conditionMap.get("pkSupplier").toString();
                logger.info("pkSupplier--"+pkSupplier);
            }
        }
        if(StringUtils.isNotEmpty(pkProject)){
            queryParam.getParams().put("pk_project", new Parameter(QueryParam.EQ, pkProject));
        }
        if(StringUtils.isNotEmpty(pkSupplier)){
            queryParam.getParams().put("pk_supplier", new Parameter(QueryParam.EQ, pkSupplier));
        }
        //queryParam.getOrderMap().put("checkDate", QueryParam.DESC);
        //IPage<Stordoc> page = calBodyService.queryPage(queryParam,false);
        Page<CmContract> page = new Page<>((long)queryParam.getPageIndex(), (long)queryParam.getPageSize());
        QueryWrapper wrapper = changeToQueryWrapper(queryParam);
        List<CmContract> listres = cmContractService.querySubCmContract(page,wrapper,supplierId,pkCorp);
        IPage<CmContract> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(listres);
        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    @RequestMapping(value = "queryContractRef", method= RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<CmContract>> queryContractRef(
            @RequestParam(value = "pkCorp", required=false) String pkCorp,
            @RequestParam(defaultValue = "1") Integer pageNumber,
            @RequestParam(defaultValue = "10") Integer pageSize,
            @RequestParam(value = "condition", required = false) String condition,
            @RequestParam(value = "searchText", required = false) String searchText) {
        /** 模糊搜索配置字段示例 */
        QueryParam queryParam = new QueryParam();
        queryParam.setPageIndex(pageNumber);
        queryParam.setPageSize(pageSize);
        queryParam.setSearchText(searchText);
        List<String> fuzzyFields = queryParam.getFuzzyFields();
        fuzzyFields.add("contractname");
        fuzzyFields.add("contractcode");
        fuzzyFields.add("suppliername");
        /*if(StringUtils.isNotEmpty(pkCorp)){
            queryParam.getParams().put("pkCorp", new Parameter(QueryParam.EQ, pkCorp));
        }*/
        /** 租户隔离 */
        Long supplierId = null;
        String pkProject = null;
        String pkSupplier = null;
        if(StringUtils.isNotBlank(condition)) {
            Map<String, Object> conditionMap = JSONObject.parseObject(condition, Map.class);
            if(null != conditionMap.get("supplierId")) {
                supplierId = Long.valueOf(conditionMap.get("supplierId").toString());
                logger.info("参数supplierId--"+supplierId);
            }
            if(null != conditionMap.get("pkProject")) {
                pkProject = conditionMap.get("pkProject").toString();
                logger.info("pkProject--"+pkProject);
            }
            if(null != conditionMap.get("pkSupplier")) {
                pkSupplier = conditionMap.get("pkSupplier").toString();
                logger.info("pkSupplier--"+pkSupplier);
            }
            if(null != conditionMap.get("pkCorp")) {
                pkCorp =  conditionMap.get("pkCorp").toString();
                logger.info("参数pkCorp--"+pkCorp);
            }
        }
        if(StringUtils.isNotEmpty(pkProject)){
            queryParam.getParams().put("pk_project", new Parameter(QueryParam.EQ, pkProject));
        }
        if(StringUtils.isNotEmpty(pkSupplier)){
            queryParam.getParams().put("pk_supplier", new Parameter(QueryParam.EQ, pkSupplier));
        }
        if (pkProject == null) {
            throw new BusinessException("自建项目无法关联合同！");
        }

        //queryParam.getOrderMap().put("checkDate", QueryParam.DESC);
        //IPage<Stordoc> page = calBodyService.queryPage(queryParam,false);
        Page<CmContract> page = new Page<>((long)queryParam.getPageIndex(), (long)queryParam.getPageSize());
        QueryWrapper wrapper = changeToQueryWrapper(queryParam);
        List<CmContract> listres = cmContractService.queryContractRef(page,wrapper,supplierId,pkCorp);
        IPage<CmContract> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(listres);
        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    @RequestMapping(value = "queryMatContractById", method= RequestMethod.GET)
    @ResponseBody
    public CommonResponse<CmContract> queryMatContractById(@RequestParam(value = "contractId") String contractId) {

        logger.info("传入参数contractId--controller---: {}", contractId);
        CmContract entity = cmContractService.queryMatContractById(contractId);
        return CommonResponse.success("查询单个合同实体成功！", entity);
    }

    @RequestMapping(value = "querySubContractByCorp", method= RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<CmContract>> querySubContractByCorp(
            @RequestParam(value = "pkCorp", required=false) String pkCorp,
            @RequestParam(defaultValue = "1") Integer pageNumber,
            @RequestParam(defaultValue = "10") Integer pageSize,
            @RequestParam(value = "condition", required = false) String condition,
            @RequestParam(value = "searchText", required = false) String searchText) {
        /** 模糊搜索配置字段示例 */
        QueryParam queryParam = new QueryParam();
        queryParam.setPageIndex(pageNumber);
        queryParam.setPageSize(pageSize);
        queryParam.setSearchText(searchText);
        List<String> fuzzyFields = queryParam.getFuzzyFields();
        fuzzyFields.add("contractname");
        fuzzyFields.add("contractcode");
        fuzzyFields.add("suppliername");
        if(StringUtils.isNotEmpty(pkCorp)){
            queryParam.getParams().put("pkCorp", new Parameter(QueryParam.EQ, pkCorp));
        }
        /** 租户隔离 */
        Long supplierId = null;
        String pkProject = null;
        String pkSupplier = null;
        if(StringUtils.isNotBlank(condition)) {
            Map<String, Object> conditionMap = JSONObject.parseObject(condition, Map.class);
            if(null != conditionMap.get("supplierId")) {
                supplierId = Long.valueOf(conditionMap.get("supplierId").toString());
                logger.info("参数supplierId--"+supplierId);
            }
            if(null != conditionMap.get("pkProject")) {
                pkProject = conditionMap.get("pkProject").toString();
                logger.info("pkProject--"+pkProject);
            }
            if(null != conditionMap.get("pkSupplier")) {
                pkSupplier = conditionMap.get("pkSupplier").toString();
                logger.info("pkSupplier--"+pkSupplier);
            }
            if(null != conditionMap.get("pkCorp")) {
                pkCorp =  conditionMap.get("pkCorp").toString();
                logger.info("参数pkCorp--"+pkCorp);
            }
        }
        if(StringUtils.isNotEmpty(pkProject)){
            queryParam.getParams().put("pk_project", new Parameter(QueryParam.EQ, pkProject));
        }
        if(StringUtils.isNotEmpty(pkSupplier)){
            queryParam.getParams().put("pk_supplier", new Parameter(QueryParam.EQ, pkSupplier));
        }

        /** 数据隔离，如果当前登录组织为项目部，查询orgId，否则查询parentOrgId本下 */
        if(OrgVO.ORG_TYPE_DEPARTMENT.toString().equals(InvocationInfoProxy.getOrgType())){
            CommonResponse<OrgVO> orgVo = orgApi.getOneById(InvocationInfoProxy.getOrgId());
            queryParam.getParams().put("pkProject", new Parameter(QueryParam.EQ, orgVo.getData().getSourceId()));
        } else {
            queryParam.getParams().put("pkCorp", new Parameter(QueryParam.IN, orgApi.findChildrenByParentIdWithoutProjectDept(
                    InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getSourceId).collect(Collectors.toList())));
        }

        //queryParam.getOrderMap().put("checkDate", QueryParam.DESC);
        //IPage<Stordoc> page = calBodyService.queryPage(queryParam,false);
        Page<CmContract> page = new Page<>((long)queryParam.getPageIndex(), (long)queryParam.getPageSize());
        QueryWrapper wrapper = changeToQueryWrapper(queryParam);
        List<CmContract> listres = cmContractService.querySubCmContract(page,wrapper,supplierId,pkCorp);
        IPage<CmContract> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(listres);
        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 分包合同列表查询
     * @param pkProject	项目主键
     * @return
     */
    @RequestMapping(value = "querySubContractList", method= RequestMethod.GET)
    @ResponseBody
    public CommonResponse<List<CmContract>> querySubContractList(
            @RequestParam(value = "pkProject") String pkProject,
            @RequestParam(value = "searchText", required = false) String searchText){
        /** 模糊搜索配置字段示例 */
        QueryParam queryParam = new QueryParam();
        queryParam.setSearchText(searchText);
        List<String> fuzzyFields = queryParam.getFuzzyFields();
        fuzzyFields.add("suppliername");
        queryParam.getParams().put("pk_project", new Parameter(QueryParam.EQ, pkProject));

        QueryWrapper wrapper = changeToQueryWrapper(queryParam);
        List<CmContract> listres = cmContractService.querySubCmContractList(wrapper);
        return CommonResponse.success("查询列表数据成功！", listres);
    }
}
